==> spring-web-2.8.4-sources.jar: cn/ipokerface/web/controller/ControllerExceptionHandler.java <==
package cn.ipokerface.web.controller;

import cn.ipokerface.common.exception.ServiceCodeException;
import cn.ipokerface.common.exception.ServiceResultException;
import cn.ipokerface.common.logback.LoggerAdapter;
import cn.ipokerface.common.model.api.ResultBody;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.annotation.Order;
import org.springframework.web.HttpRequestMethodNotSupportedException;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.MissingServletRequestParameterException;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;

/**
 * Created by       mac
 * Create Date      2020/12/11
 * Version          1.0.0
 * Description:
 */


@Order(Integer.MAX_VALUE)
@Configuration
@ControllerAdvice
public class ControllerExceptionHandler extends LoggerAdapter {

    @ResponseBody
    @ExceptionHandler(value = Exception.class)
    public ResultBody exceptionHandler(Exception ex) {
        ResultBody.Builder builder = ResultBody.builder();

        if (ex instanceof NumberFormatException) {
            builder.error(ResultBody.Result.ERROR_ARGUMENT.getCode(), ex.getMessage());
        }
        else if (ex instanceof IllegalArgumentException || ex instanceof EnumConstantNotPresentException) {
            builder.error(ResultBody.Result.ERROR_ARGUMENT.getCode(), ex.getMessage());
        }
        else if (ex instanceof MissingServletRequestParameterException) {
            builder.error(ResultBody.Result.ERROR_ARGUMENT.getCode(), ex.getMessage());
        }
        else if (ex instanceof HttpRequestMethodNotSupportedException) {
            builder.error(ResultBody.Result.ERROR_METHOD.getCode(), ex.getMessage());
        }
        else if (ex instanceof MethodArgumentNotValidException) {
            MethodArgumentNotValidException exception = (MethodArgumentNotValidException) ex;
            exception.getBindingResult().getFieldError().getDefaultMessage();
            builder.error(ResultBody.Result.ERROR_ARGUMENT.getCode(),exception.getBindingResult().getFieldError().getDefaultMessage());
        }
        else if (ex instanceof ServiceResultException) {
            ServiceResultException exception = (ServiceResultException) ex;
            return exception.getBody();
        }
        else if (ex instanceof ServiceCodeException) {
            ServiceCodeException exception = (ServiceCodeException) ex;
            return ResultBody.error(exception.getCode(), exception.getMessage());
        }
        else {
            builder.error(ResultBody.Result.ERROR.getCode(), ex.getMessage());
        }

        // 输出ex日志
        error(ex);

        return builder.build();
    }
}

==> spring-web-2.8.6-sources.jar: cn/ipokerface/web/controller/ControllerExceptionHandler.java <==
package cn.ipokerface.web.controller;

import cn.ipokerface.common.exception.ServiceCodeException;
import cn.ipokerface.common.exception.ServiceResultException;
import cn.ipokerface.common.logback.LoggerAdapter;
import cn.ipokerface.common.model.api.ResultBody;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.annotation.Order;
import org.springframework.validation.BindException;
import org.springframework.validation.ObjectError;
import org.springframework.web.HttpRequestMethodNotSupportedException;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.MissingServletRequestParameterException;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;

import java.util.List;

/**
 * Created by       mac
 * Create Date      2020/12/11
 * Version          1.0.0
 * Description:
 */


@Order(Integer.MAX_VALUE)
@Configuration
@ControllerAdvice
public class ControllerExceptionHandler extends LoggerAdapter {

    @ResponseBody
    @ExceptionHandler(value = Exception.class)
    public ResultBody exceptionHandler(Exception ex) {
        ResultBody.Builder builder = ResultBody.builder();

        if (ex instanceof NumberFormatException) {
            builder.error(ResultBody.Result.ERROR_ARGUMENT.getCode(), ex.getMessage());
        }
        else if (ex instanceof IllegalArgumentException || ex instanceof EnumConstantNotPresentException) {
            builder.error(ResultBody.Result.ERROR_ARGUMENT.getCode(), ex.getMessage());
        }
        else if (ex instanceof MissingServletRequestParameterException) {
            builder.error(ResultBody.Result.ERROR_ARGUMENT.getCode(), ex.getMessage());
        }
        else if (ex instanceof HttpRequestMethodNotSupportedException) {
            builder.error(ResultBody.Result.ERROR_METHOD.getCode(), ex.getMessage());
        }
        else if (ex instanceof MethodArgumentNotValidException) {
            MethodArgumentNotValidException exception = (MethodArgumentNotValidException) ex;
            exception.getBindingResult().getFieldError().getDefaultMessage();
            builder.error(ResultBody.Result.ERROR_ARGUMENT.getCode(),exception.getBindingResult().getFieldError().getDefaultMessage());
        }
        else if (ex instanceof BindException) {
            BindException exception = (BindException) ex;
            List<ObjectError> errorList = exception.getBindingResult().getAllErrors();
            StringBuffer stringBuffer = new StringBuffer();
            if (CollectionUtils.isNotEmpty(errorList)) {
                errorList.stream().forEach(item->{
                    if (StringUtils.isNotEmpty(stringBuffer.toString())) stringBuffer.append(",");
                    stringBuffer.append(item.getDefaultMessage());
                });
            }
            builder.error(ResultBody.Result.ERROR_ARGUMENT.getCode(), stringBuffer.toString());
        }
        else if (ex instanceof ServiceResultException) {
            ServiceResultException exception = (ServiceResultException) ex;
            return exception.getBody();
        }
        else if (ex instanceof ServiceCodeException) {
            ServiceCodeException exception = (ServiceCodeException) ex;
            return ResultBody.error(exception.getCode(), exception.getMessage());
        }
        else {
            builder.error(ResultBody.Result.ERROR.getCode(), ex.getMessage());
        }

        // 输出ex日志
        error(ex);

        return builder.build();
    }
}
